import Vue from 'vue'
import Router from 'vue-router'

Vue.use(Router)

/* Layout */
import Layout from '@/layout'

/**
 * Note: sub-menu only appear when route children.length >= 1
 * Detail see: https://panjiachen.github.io/vue-element-admin-site/guide/essentials/router-and-nav.html
 *
 * hidden: true                   if set true, item will not show in the sidebar(default is false)
 * alwaysShow: true               if set true, will always show the root menu
 *                                if not set alwaysShow, when item has more than one children route,
 *                                it will becomes nested mode, otherwise not show the root menu
 * redirect: noRedirect           if set noRedirect will no redirect in the breadcrumb
 * name:'router-name'             the name is used by <keep-alive> (must set!!!)
 * meta : {
    roles: ['admin','editor']    control the page roles (you can set multiple roles)
    title: 'title'               the name show in sidebar and breadcrumb (recommend set)
    icon: 'svg-name'             the icon show in the sidebar
    breadcrumb: false            if set false, the item will hidden in breadcrumb(default is true)
    activeMenu: '/example/list'  if set path, the sidebar will highlight the path you set
  }
 */

/**
 * constantRoutes
 * a base page that does not have permission requirements
 * all roles can be accessed
 */
export const constantRoutes = [
  {
    path: '/login',
    component: () => import('@/views/login/index'),
    hidden: true
  },

  {
    path: '/404',
    component: () => import('@/views/404'),
    hidden: true
  },
  {
    path: '/',
    redirect: '/main', // 首页
    component: Layout,
    children: [
      {
        path: 'main',
        name: 'main',
        component: () => import('@/views/main/index'),
        meta: { title: '首页' }
      }
    ]
  },
  {
    path: '/teamDetail', // 乐团详情
    component: Layout,
    meta: { title: '乐团详情' },
    children: [
      {
        path: 'teamDetail',
        name: 'teamDetail',
        component: () => import('@/views/teamDetail/index'),
        meta: { title: '乐团详情' },
      },
      {
        path: 'studentSignin',
        name: 'studentSignin',
        component: () => import('@/views/teamDetail/components/studentSignin'),
        meta: { title: '学生点名' }
      },
      {
        path: 'teacherSignin',
        name: 'teacherSignin',
        component: () => import('@/views/teamDetail/components/teacherSignin'),
        meta: { title: '老师上课记录' }
      }
    ]
  },
  {
    path: '/teamBuild', // 创建乐团
    component: Layout,
    children: [
      {
        path: 'teamBuild',
        name: 'teamBuild',
        component: () => import('@/views/teamBuild/index'),
        meta: { title: '创建乐团' }
      }
    ]
  },
  {
    path: '/vipClass', // 小课
    component: Layout,
    meta: { title: 'vip管理' },
    children: [
      {
        path: 'vipClass',
        name: 'vipClass',
        component: () => import('@/views/vipClass/vipList'),
        meta: { title: 'vip课列表' }
      },
      {
        path: 'vipDetail',
        name: 'vipDetail',
        component: () => import('@/views/vipClass/vipDetail/index'),
        meta: { title: '调整记录' }
      },
      {
        path: 'resetClass',
        name: 'resetClass',
        component: () => import('@/views/vipClass/resetClasss'),
        meta: { title: 'vip课详情' }
      }
    ]
  }, {
    path: '/teacher',
    component: Layout,
    redirect: '/teacher/teacherList',
    meta: { title: '老师管理' },
    children: [
      {
        path: 'teacherList',
        name: 'teacherList',
        meta: { title: '老师列表' },
        component: () => import('@/views/teacherManager/teacherList')
      },
      {
        path: 'teacherDetail',
        name: 'teacherDetail',
        meta: { title: '老师详情' },
        component: () => import('@/views/teacherManager/teacherDetail/index')
      }
    ]
  }, {
    path: '/student',
    component: Layout,
    redirect: '/student/studentList',
    meta: { title: '学生管理' },
    children: [
      {
        path: 'studentList',
        meta: { title: '学生列表' },
        component: () => import('@/views/studentManager/studentList'),
      },
      {
        path: 'studentdetaile',
        meta: { title: '学员详情' },
        component: () => import('@/views/studentManager/index'),
      }
    ]
  }, {
    path: '/business',
    component: Layout,
    redirect: '/business/orderManager/income',
    meta: { title: '交易管理' },
    children: [
      {
        path: 'order',
        meta: { title: '订单管理' },
        component: () => import('@/views/businessManager/orderManager/index'),// Parent router-view
        children: [{
          path: 'income',
          meta: { title: '收入' },
          component: () => import('@/views/businessManager/orderManager/income')
        }, {
          path: 'backMoney',
          meta: { title: '退费管理' },
          component: () => import('@/views/businessManager/orderManager/backMoney')
        }, {
          path: 'expend',
          meta: { title: '支出' },
          component: () => import('@/views/businessManager/orderManager/expend')
        }]
      },
      {
        path: 'shopManager',
        meta: { title: '商品管理' },
        component: () => import('@/views/businessManager/shopManager/index'),
        children: [
          {
            path: 'shopList',
            meta: { title: '商品列表' },
            component: () => import('@/views/businessManager/shopManager/shopList')
          },
          {
            path: 'shopCategroy',
            meta: { title: '商品分类' },
            component: () => import('@/views/businessManager/shopManager/shopCategory')
          }

        ]
      }
    ]
  },
  {
    path: '/categoryManager',
    component: Layout,
    meta: { title: '系统内部管理' },
    children: [{
      path: 'adminManager',
      name: 'adminManager',
      meta: { title: '权限管理' },
      component: () => import('@/views/categroyManager/adminManager')
    },
    {
      path: 'staffManager',
      name: 'staffManager',
      meta: { title: '员工管理' },
      component: () => import('@/views/categroyManager/staffManager')
    }, {
      path: 'branchManager',
      name: 'branchManager',
      meta: { title: '合作单位' },
      component: () => import('@/views/categroyManager/branchManager')
    }, {
      path: 'addressManager',
      name: 'addressManager',
      meta: { title: '教学点管理' },
      component: () => import('@/views/categroyManager/addressManager')
    }
    ]
  },
  {
    path: '/example',
    component: Layout,
    redirect: '/example/table',
    name: 'Example',
    meta: { title: 'Example', icon: 'example' },
    children: [
      {
        path: 'table',
        name: 'Table',
        component: () => import('@/views/table/index'),
        meta: { title: 'Table' }
      },
      {
        path: 'tree',
        name: 'Tree',
        component: () => import('@/views/tree/index'),
        meta: { title: 'Tree' }
      }
    ]
  },

  {
    path: '/form',
    component: Layout,
    children: [
      {
        path: 'index',
        name: 'Form',
        component: () => import('@/views/form/index'),
        meta: { title: 'Form' }
      }
    ]
  },

  {
    path: '/nested',
    component: Layout,
    redirect: '/nested/menu1',
    name: 'Nested',
    meta: {
      title: 'Nested',
      icon: 'nested'
    },
    children: [
      {
        path: 'menu1',
        component: () => import('@/views/nested/menu1/index'), // Parent router-view
        name: 'Menu1',
        meta: { title: 'Menu1' },
        children: [
          {
            path: 'menu1-1',
            component: () => import('@/views/nested/menu1/menu1-1'),
            name: 'Menu1-1',
            meta: { title: 'Menu1-1' }
          },
          {
            path: 'menu1-2',
            component: () => import('@/views/nested/menu1/menu1-2'),
            name: 'Menu1-2',
            meta: { title: 'Menu1-2' },
            children: [
              {
                path: 'menu1-2-1',
                component: () => import('@/views/nested/menu1/menu1-2/menu1-2-1'),
                name: 'Menu1-2-1',
                meta: { title: 'Menu1-2-1' }
              },
              {
                path: 'menu1-2-2',
                component: () => import('@/views/nested/menu1/menu1-2/menu1-2-2'),
                name: 'Menu1-2-2',
                meta: { title: 'Menu1-2-2' }
              }
            ]
          },
          {
            path: 'menu1-3',
            component: () => import('@/views/nested/menu1/menu1-3'),
            name: 'Menu1-3',
            meta: { title: 'Menu1-3' }
          }
        ]
      },
      {
        path: 'menu2',
        component: () => import('@/views/nested/menu2/index'),
        meta: { title: 'menu2' }
      }
    ]
  },

  {
    path: 'external-link',
    component: Layout,
    children: [
      {
        path: 'https://panjiachen.github.io/vue-element-admin-site/#/',
        meta: { title: 'External Link' }
      }
    ]
  },

  // 404 page must be placed at the end !!!
  { path: '*', redirect: '/404', hidden: true }
]

const createRouter = () => new Router({
  // mode: 'history', // require service support
  scrollBehavior: () => ({ y: 0 }),
  routes: constantRoutes
})

const router = createRouter()

// Detail see: https://github.com/vuejs/vue-router/issues/1234#issuecomment-357941465
export function resetRouter () {
  const newRouter = createRouter()
  router.matcher = newRouter.matcher // reset router
}

export default router
